pyrasa.utils.fit\_funcs.KneeFitFun
==================================

.. currentmodule:: pyrasa.utils.fit_funcs

.. autoclass:: KneeFitFun
   :special-members: __contains__,__getitem__,__iter__,__len__,__add__,__sub__,__mul__,__div__,__neg__,__hash__
   :members:

.. _sphx_glr_backreferences_pyrasa.utils.fit_funcs.KneeFitFun:

.. minigallery:: pyrasa.utils.fit_funcs.KneeFitFun
    :add-heading: